# Medium multiply
A simple library to download music easy.

### Installation
```
pip install Music_Downloader
```

### Get started
How to multiply one number by another with this lib:

```Python
from MusicDownloader import MusicDownloader

# Call the download method
MusicDownloader.download(urls,download_path,faild_file)
```